<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/vod/abstract_vod.php';
require_once 'lib/vod/movie.php';

const VOD_FAVORITES = '/config/tptv.vod.favorites';

///////////////////////////////////////////////////////////////////////////

class RodnoeVod extends AbstractVod
{
    private $session;

    public function __construct($session)
    {
        $this->session = $session;

        parent::__construct(true, true, false);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_vod_info(MediaURL $media_url, &$plugin_cookies)
    {
        $this->session->ensure_logged_in($plugin_cookies);

        return parent::get_vod_info($media_url, &$plugin_cookies);
    }

    public function try_load_movie($movie_id, &$plugin_cookies)
    {
        $movie = $this->session->api_vod_info($movie_id);

        $this->set_cached_movie($movie);
    }

    public function get_vod_stream_url($playback_url, &$plugin_cookies)
    {
		// get saved protect code
        $movie = $this->get_cached_movie($playback_url);
		$protect_code = $movie->protect_code;

		$doc = $this->session->api_get_url_movie($playback_url, $protect_code);
        $url = strval($doc->url);
        hd_print("~~~~~~~ get_vod_stream_url $url");

		// clear saved protect code
		$movie->protect_code = null;
		$this->set_cached_movie($movie);

        return $url;
    }

    ///////////////////////////////////////////////////////////////////////
    // Favorites.

    protected function load_favorites(&$plugin_cookies)
    {
        $ids = file(VOD_FAVORITES, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
		if(!$ids)
		{
			hd_print("Error reading VOD favorites file");
			$this->set_fav_movie_ids(array());
			return;
		}
		
		$fav_movie_ids = array();
		foreach($ids as $id)
		{
			try
			{
				$this->try_load_movie($id, $plugin_cookies);
				$fav_movie_ids[] = $id;
			}
			catch(Exception $e){}
		}
		
        $this->set_fav_movie_ids($fav_movie_ids);
        hd_print('The ' . count($fav_movie_ids) . ' favorite movies loaded.'); 
    }

    protected function do_add_favorite_movie($movie_id, &$plugin_cookies)
    {
		file_put_contents(VOD_FAVORITES, "$movie_id\n", FILE_APPEND);
    }

    protected function do_remove_favorite_movie($movie_id, &$plugin_cookies)
    {
        $ids = file(VOD_FAVORITES, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
		if(!$ids)
			$ids = array();
		
		file_put_contents(VOD_FAVORITES, "");
		foreach($ids as $id)
			if($id != $movie_id)
				file_put_contents(VOD_FAVORITES, "$id\n", FILE_APPEND);
			
    }

    ///////////////////////////////////////////////////////////////////////
    // Genres.

    protected function load_genres(&$plugin_cookies)
    {
        $doc = $this->session->api_get_genre_movie();

        $genres = array();
        foreach ($doc->groups->item as $genre)
            $genres[intval($genre->id)] = strval($genre->title);
        return $genres;
    }

    public function get_genre_icon_url($genre_id)
    {
        return $this->session->get_icon('movies_genres.png');
    }

    public function get_genre_media_url_str($genre_id)
    {
        return RodnoeVodListScreen::get_media_url_str('genres', $genre_id);
    }

    ///////////////////////////////////////////////////////////////////////
    // Search.

    public function get_search_media_url_str($pattern)
    {
        return RodnoeVodListScreen::get_media_url_str('search', $pattern);
    }

    ///////////////////////////////////////////////////////////////////////
    // Folder views.

    public function get_vod_genres_folder_views()
    {
        $mov_genre_default_icon_url = $this->session->get_icon('movies_genres.png');

        return array(
            array
            (
                PluginRegularFolderView::async_icon_loading => false,

                PluginRegularFolderView::view_params => array
                (
                    ViewParams::num_cols => 3,
                    ViewParams::num_rows => 10,
#                    ViewParams::content_box_padding_bottom => 110,
                ),

                PluginRegularFolderView::base_view_item_params => array
                (
                    ViewItemParams::item_padding_top => 0,
                    ViewItemParams::item_padding_bottom => 0,
                    ViewItemParams::icon_valign => VALIGN_CENTER,
                    ViewItemParams::item_layout => HALIGN_LEFT,
                    ViewItemParams::item_caption_width => 365,
                    ViewItemParams::icon_dx => 65,
                    ViewItemParams::icon_width => 75,
                    ViewItemParams::icon_height => 43,
                ),

                PluginRegularFolderView::not_loaded_view_item_params => array
                (
                    ViewItemParams::icon_path => $mov_genre_default_icon_url,
                ),
            ));
    }

    public function get_vod_list_folder_views()
    {
        $mov_unset_url = $this->session->get_icon('mov_unset.png');
        return array(
            array
            (
                PluginRegularFolderView::async_icon_loading => true,

                PluginRegularFolderView::view_params => array
                (
                    ViewParams::num_cols => 4,
                    ViewParams::num_rows => 2,
                    ViewParams::icon_selection_box_width => 242,
                    ViewParams::icon_selection_box_height => 375,
                    ViewParams::paint_details => true,
                    ViewParams::zoom_detailed_icon => false,
                ),

                PluginRegularFolderView::base_view_item_params => array
                (
                    ViewItemParams::item_padding_top => 0,
                    ViewItemParams::item_padding_bottom => 0,
                    ViewItemParams::icon_valign => VALIGN_CENTER,
                    ViewItemParams::item_paint_caption => false,
                    ViewItemParams::icon_scale_factor => 0.6,
                    ViewItemParams::icon_sel_scale_factor => 0.7,
                ),

                PluginRegularFolderView::not_loaded_view_item_params => array
                (
                    ViewItemParams::icon_path => $mov_unset_url,
                    ViewItemParams::item_detailed_icon_path => 'missing://',
                    ViewItemParams::item_paint_caption_within_icon => true,
                    ViewItemParams::item_caption_within_icon_color => 'black',
                ),
            ));
    }

    public function get_archive(MediaURL $media_url)
    {
        return null; // $this->session->get_archive();
    }

    public function folder_entered(MediaURL $media_url, &$plugin_cookies)
    {
        $this->session->ensure_logged_in($plugin_cookies);
    }

    public function get_buffering_ms()
    {
        return 3000;
    }
}

///////////////////////////////////////////////////////////////////////////
?>
